@@ -6,7 +6,11 @@ module FactoryBotRails
       end
 
       def run
-        @generators.test_framework test_framework, fixture: false, fixture_replacement: :factory_bot
+        @generators.test_framework(
+          test_framework,
+          fixture: false,
+          fixture_replacement: :factory_bot,
+        )
       end
 
       private
